CertificateChoiceNotificationRequest

Struct CertificateChoiceNotificationRequest 

pub struct CertificateChoiceNotificationRequest {
    pub relying_party_uuid: String,
    pub relying_party_name: String,
    pub initial_callback_url: Option<String>,
    pub certificate_level: CertificateLevel,
    pub nonce: Option<String>,
    pub capabilities: Option<Vec<String>>,
    pub request_properties: Option<RequestProperties>,
}
Certificate Choice Notification Request

This struct represents a request for choosing a certificate with the Smart ID service. It includes various parameters required for the certificate choice process.

Properties

  • relying_party_uuid - The UUID of the relying party, provided by Smart ID.
  • relying_party_name - The name of the relying party, provided by Smart ID.
  • initial_callback_url - The initial callback URL for the request, used for device link flows (not be required in QR flows).
  • certificate_level - The level of the certificate required for the request.
  • nonce - An optional nonce for the request.
  • capabilities - Used only when agreed with Smart-ID provider. When omitted request capabilities are derived from certificateLevel parameter.
  • request_properties - Optional properties for the request.

Example

use smart_id_rust_client::config::SmartIDConfig;
use smart_id_rust_client::models::api::certificate_choice_session::CertificateChoiceDeviceLinkRequest;

fn create_certificate_choice_request(cfg: &SmartIDConfig) -> CertificateChoiceDeviceLinkRequest {
    CertificateChoiceDeviceLinkRequest::new(cfg)
}

Fields

relying_party_uuid: Stringrelying_party_name: Stringinitial_callback_url: Option<String>certificate_level: CertificateLevelnonce: Option<String>capabilities: Option<Vec<String>>request_properties: Option<RequestProperties>

Implementations