pub struct SessionCertificate {
pub value: String,
pub certificate_level: CertificateLevel,
}Expand description
Session Certificate
This struct represents the certificate used in a session with the Smart ID service. During an auth flow a certificate that is non-repudiation capable is returned, for signing flows a certificate that is digital signature capable is returned.
Properties
value- The certificate value, DER+Base64 encoded. The certificate itself contains info on whether the certificate is QSCD-enabled, data which is not represented by certificate level.certificate_level- The level of the certificate.
Fields
value: Stringcertificate_level: CertificateLevelTrait Implementations
Sourceimpl Clone for SessionCertificate
impl Clone for SessionCertificate
Sourcefn clone(&self) -> SessionCertificate
fn clone(&self) -> SessionCertificate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionCertificate
impl Debug for SessionCertificate
Sourceimpl Default for SessionCertificate
impl Default for SessionCertificate
Sourcefn default() -> SessionCertificate
fn default() -> SessionCertificate
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionCertificate
impl<'de> Deserialize<'de> for SessionCertificate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SessionCertificate
impl PartialEq for SessionCertificate
Sourceimpl Serialize for SessionCertificate
impl Serialize for SessionCertificate
impl StructuralPartialEq for SessionCertificate