pub struct SessionResult {
pub end_result: EndResult,
pub document_number: Option<String>,
}Expand description
Session Result
This struct represents the result of a session with the Smart ID service. It is part of the session status response.
Properties
end_result- The end result of the session. OK for success, otherwise an error.document_number- The document number associated with the session, if available. Can be used in further signature and authentication requests.
Fields
end_result: EndResultdocument_number: Option<String>Trait Implementations
Sourceimpl Clone for SessionResult
impl Clone for SessionResult
Sourcefn clone(&self) -> SessionResult
fn clone(&self) -> SessionResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionResult
impl Debug for SessionResult
Sourceimpl Default for SessionResult
impl Default for SessionResult
Sourcefn default() -> SessionResult
fn default() -> SessionResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionResult
impl<'de> Deserialize<'de> for SessionResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SessionResult
impl PartialEq for SessionResult
Sourceimpl Serialize for SessionResult
impl Serialize for SessionResult
impl StructuralPartialEq for SessionResult