pub struct SessionStatusResponse {
pub state: SessionState,
pub result: Option<SessionResult>,
pub signature_protocol: Option<SignatureProtocol>,
pub signature: Option<ResponseSignature>,
pub cert: Option<SessionCertificate>,
pub ignored_properties: Option<Vec<String>>,
pub interaction_type_used: Option<InteractionFlow>,
pub device_ip_address: Option<String>,
}Expand description
Session Status
This struct represents the status of a session with the Smart ID service. It is returned from the Smart ID service session status endpoint.
Properties
state- The current state of the session, eitherRUNNINGorCOMPLETE.result- The result of the session, if available. result.endResult will beOKif the session was successful.signature_protocol- The protocol used for the signature, if available.signature- The signature response, if available.cert- The session certificate, if available. Contains the level of the certificate and the certificate value DER+Base64 encoded.ignored_properties- Any values from requestProperties that were unsupported or ignored.interaction_type_used- The interaction flow used during the session, if available.device_ip_address- The IP address of the mobile device, if it was requested using “shareMdClientIpAddress” in the session creation parameters.
Fields
state: SessionStateresult: Option<SessionResult>signature_protocol: Option<SignatureProtocol>signature: Option<ResponseSignature>cert: Option<SessionCertificate>ignored_properties: Option<Vec<String>>interaction_type_used: Option<InteractionFlow>device_ip_address: Option<String>Trait Implementations
Sourceimpl Clone for SessionStatusResponse
impl Clone for SessionStatusResponse
Sourcefn clone(&self) -> SessionStatusResponse
fn clone(&self) -> SessionStatusResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionStatusResponse
impl Debug for SessionStatusResponse
Sourceimpl Default for SessionStatusResponse
impl Default for SessionStatusResponse
Sourcefn default() -> SessionStatusResponse
fn default() -> SessionStatusResponse
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionStatusResponse
impl<'de> Deserialize<'de> for SessionStatusResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SessionStatusResponse
impl PartialEq for SessionStatusResponse
Sourceimpl Serialize for SessionStatusResponse
impl Serialize for SessionStatusResponse
impl StructuralPartialEq for SessionStatusResponse