SignatureDeviceLinkRequest

Struct SignatureDeviceLinkRequest 

pub struct SignatureDeviceLinkRequest {
    pub relying_party_uuid: String,
    pub relying_party_name: String,
    pub initial_callback_url: Option<String>,
    pub certificate_level: CertificateLevel,
    pub signature_protocol: SignatureProtocol,
    pub signature_protocol_parameters: SignatureProtocolParameters,
    pub nonce: Option<String>,
    pub interactions: String,
    pub request_properties: Option<RequestProperties>,
    pub capabilities: Option<Vec<String>>,
}
Signature Device Link Request

This struct represents a request for a signature session triggered by clicking on a link or scanning a qr code.

Properties

  • relying_party_uuid - The UUID of the relying party, provided by Smart ID.
  • relying_party_name - The name of the relying party, provided by Smart ID.
  • initial_callback_url - The initial callback URL for the signature session. This is used to redirect the user after the signature is completed.
  • certificate_level - The level of the certificate required for the signature.
  • signature_protocol - The protocol used for the signature.
  • signature_protocol_parameters - The parameters for the signature protocol.
  • interactions - A base64 encoded JSON string of interactions allowed during the signature session. At least one interaction is required. Interactions are limited based on the flow type, look at the Interaction documentation for more information.
  • nonce - An optional nonce for the request.
  • request_properties - Optional properties for the request.
  • capabilities - Used only when agreed with Smart-ID provider. When omitted, request capabilities are derived from the certificate_level parameter.

Example

use smart_id_rust_client::config::SmartIDConfig;
use smart_id_rust_client::models::api::signature_session::SignatureDeviceLinkRequest;
use smart_id_rust_client::models::interaction::Interaction;
use smart_id_rust_client::models::signature::{HashingAlgorithm, SignatureAlgorithm};
use smart_id_rust_client::error::Result;

fn create_signature_request(cfg: &SmartIDConfig) -> Result<SignatureDeviceLinkRequest> {
    let interactions = vec![Interaction::DisplayTextAndPIN {
        display_text_60: "Sign document".to_string(),
    }];
    SignatureDeviceLinkRequest::new(
        cfg,
        interactions,
        "base64-encoded-digest".to_string(),
        SignatureAlgorithm::RsassaPss,
        HashingAlgorithm::sha_256,
        Some("https://example.com/callback".to_string()),
    )
}

Fields

relying_party_uuid: Stringrelying_party_name: Stringinitial_callback_url: Option<String>certificate_level: CertificateLevelsignature_protocol: SignatureProtocolsignature_protocol_parameters: SignatureProtocolParametersnonce: Option<String>interactions: Stringrequest_properties: Option<RequestProperties>capabilities: Option<Vec<String>>

Used only when agreed with Smart-ID provider. When omitted request capabilities are derived from certificateLevel parameter.

Implementations

Source

impl SignatureDeviceLinkRequest

pub fn new( cfg: &SmartIDConfig, interactions: Vec<Interaction>, digest: String, signature_algorithm: SignatureAlgorithm, hash_algorithm: HashingAlgorithm, initial_callback_url: Option<String>, ) -> Result<Self>

Creates a new SignatureRequest.

Arguments
  • cfg - The configuration for the Smart-ID service.
  • interactions - A vector of interactions allowed during the signature session. At least one interaction is required. Interactions are limited based on the flow type, look at the Interaction documentation for more information.
  • digest - The digest to be signed. Base64 encoded.
  • signature_algorithm - The algorithm used for the signature.
  • hash_algorithm - The hashing algorithm used for the signature.
  • initial_callback_url - An optional initial callback URL for the signature session. This is used to redirect the user after the signature is completed.
Errors

Returns an error if no interactions are defined or if any interaction has invalid text length.