RequestProperties

Struct RequestProperties 

#[non_exhaustive]
pub struct RequestProperties { pub share_md_client_ip_address: bool, }
Request Properties

This struct represents the properties of a request to the Smart ID service. Currently, it only includes one property, share_md_client_ip_address.

Properties

  • share_md_client_ip_address - A boolean flag indicating whether the RP API server should share the user’s mobile device IP address with the RP. By default, it is set to false. The RP must have proper privilege to use this property. See section IP sharing for details.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
share_md_client_ip_address: bool

Whether the RP API server should share user mobile device IP address with the RP. By default it is set to false. The RP must have proper privilege to use this property. See section IP sharing for details.