Interaction

Enum Interaction 

#[non_exhaustive]
pub enum Interaction { DisplayTextAndPIN { display_text_60: String, }, ConfirmationMessage { display_text_200: String, }, VerificationCodeChoice { display_text_60: String, }, ConfirmationMessageAndVerificationCodeChoice { display_text_200: String, }, }
Represents different types of interactions that can be started on the users device

There are limitations on which interactions can be used with which request types. For device link flows, the following interactions are allowed:

  • DisplayTextAndPIN with display_text_60
  • ConfirmationMessage with display_text_200

For notificaiton flows, the following interactions are allowed:

  • VerificationCodeChoice with display_text_60
  • ConfirmationMessageAndVerificationCodeChoice with display_text_200

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DisplayTextAndPIN

Fields

display_text_60: String


ConfirmationMessage

Fields

display_text_200: String


VerificationCodeChoice

Fields

display_text_60: String


ConfirmationMessageAndVerificationCodeChoice

Fields

display_text_200: String

Implementations