#[non_exhaustive]pub enum InteractionFlow {
DisplayTextAndPIN,
ConfirmationMessage,
VerificationCodeChoice,
ConfirmationMessageAndVerificationCodeChoice,
}Expand description
Interaction Flow
This enum represents the different types of interaction flows that can be started on the user’s device. Each variant corresponds to a specific interaction type.
Variants
DisplayTextAndPIN- Displays a text message and prompts the user to enter a PIN.ConfirmationMessage- Displays a confirmation message with confirm and cancel buttons, then prompts the user to enter a pin.VerificationCodeChoice- Prompts the user to choose a verification code, then enter a pin.ConfirmationMessageAndVerificationCodeChoice- Displays a confirmation message and prompts the user to choose a verification code.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DisplayTextAndPIN
ConfirmationMessage
VerificationCodeChoice
ConfirmationMessageAndVerificationCodeChoice