#[non_exhaustive]pub enum SmartIdClientError {
Show 43 variants
ConfigMissingException(&'static str),
SerializationError(String),
RelyingPartyAccountConfigurationException(&'static str),
SmartIdClientException(&'static str),
SmartIDAPIException(String),
SessionTimeoutException,
NoSessionException,
GetSessionException,
SetSessionException,
GetUserIdentityException,
SetUserIdentityException,
GetSigningCertificateException(String),
AuthenticationSessionCompletedWithoutResult,
StatusRequestLongPollingTimeoutException,
SessionDoesNotExistOrHasExpired,
ApiClientIsTooOldException,
SystemIsUnderMaintenanceException,
SessionResponseMissingCertificate,
SessionResponseMissingSignature,
SessionResponseMissingInteractionType,
InvalidResponseSignature(String),
UserRefusedCertChoiceException,
UserRefusedConfirmationMessageException,
UserRefusedConfirmationMessageWithVerificationChoiceException,
UserRefusedDisplayTextAndPinException,
UserRefusedVerificationChoiceException,
UserSelectedWrongVerificationCodeException,
DocumentUnusableException,
NoSuitableAccountOfRequestedTypeFoundException,
PersonShouldViewSmartIdPortalException,
RequiredInteractionNotSupportedByAppException,
InvalidInteractionParametersException(&'static str),
GenerateDeviceLinkException(&'static str),
InvalidSignatureProtocal(&'static str),
FailedToValidateSessionResponseCertificate(String),
InvalidDigestException(String),
UserShouldViewSmartIDAppOrPortalException,
NotFoundException,
BadRequestException,
ClientOutdatedException,
InvalidSemanticIdentifierException(String),
ProtocolFailureException,
ServerErrorException,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConfigMissingException(&'static str)
Config Exception
SerializationError(String)
Serialization Error
RelyingPartyAccountConfigurationException(&'static str)
RelyingPartyAccountConfigurationException
SmartIdClientException(&'static str)
SmartIdClientException
SmartIDAPIException(String)
SmartIDAPIException
SessionTimeoutException
Session timed out without getting any response from user
NoSessionException
There is no running session
GetSessionException
Failed to get the running session
SetSessionException
Failed to set the running session
GetUserIdentityException
Failed to get user identity
SetUserIdentityException
Failed to set user identity
GetSigningCertificateException(String)
Get signing certificate failed
AuthenticationSessionCompletedWithoutResult
Authentication session completed without result
StatusRequestLongPollingTimeoutException
Session did not complete within timeout
SessionDoesNotExistOrHasExpired
Session does not exist or has expired
ApiClientIsTooOldException
Api client is too old and is not supported anymore
SystemIsUnderMaintenanceException
System is under maintenance and is not available
SessionResponseMissingCertificate
Session response missing certificate
SessionResponseMissingSignature
Session response missing signature
SessionResponseMissingInteractionType
Session response missing interaction type
InvalidResponseSignature(String)
Session response signature verification failed
UserRefusedCertChoiceException
User has multiple accounts and pressed Cancel on device choice screen on any device
UserRefusedConfirmationMessageException
User cancelled on confirmationMessage screen
UserRefusedConfirmationMessageWithVerificationChoiceException
User cancelled on confirmationMessageAndVerificationCodeChoice screen
UserRefusedDisplayTextAndPinException
User pressed Cancel on PIN screen
UserRefusedVerificationChoiceException
User cancelled verificationCodeChoice screen
UserSelectedWrongVerificationCodeException
User selected wrong verification code
DocumentUnusableException
DOCUMENT_UNUSABLE. User must either check his/her Smart-ID mobile application or turn to customer support for getting the exact reason.
NoSuitableAccountOfRequestedTypeFoundException
No suitable account of requested type found, but user has some other accounts
PersonShouldViewSmartIdPortalException
Person should view Smart-ID app or Smart-ID self-service portal now
RequiredInteractionNotSupportedByAppException
User app version does not support any of the allowedInteractionsOrder interactions
InvalidInteractionParametersException(&'static str)
Interaction parameters are invalid
GenerateDeviceLinkException(&'static str)
Failed to generate device link
InvalidSignatureProtocal(&'static str)
Invalid signature protocol
FailedToValidateSessionResponseCertificate(String)
Failed to validate session response certificate
InvalidDigestException(String)
Digest is not in valid format
UserShouldViewSmartIDAppOrPortalException
User should view Smart-ID app or portal
NotFoundException
Not found exception from Smart ID API
BadRequestException
Bad request exception from Smart ID API
ClientOutdatedException
Smart ID client is outdated
InvalidSemanticIdentifierException(String)
Invalid semantic identifier
ProtocolFailureException
ServerErrorException